@@ -14,7 +14,8 @@ use Path::Tiny;
 use Data::Dumper;
 
 use Config::Model::DumpAsData;
-use Dpkg::Copyright::Scanner qw/scan_files __squash __pack_files __pack_copyright __create_tree_leaf_from_paths/;
+use Dpkg::Copyright::Scanner qw/scan_files __squash __pack_files __pack_copyright
+                                __create_tree_leaf_from_paths __from_copyright_structure/;
 use Scalar::Util qw/weaken/;
 use Storable qw/dclone/;
 
@@ -41,6 +42,13 @@ sub _say ($self,$msg) {
 sub _get_old_data ($old_split_files, $old_split_dirs, $path) {
     my $data = delete $old_split_files->{$path};
 
+    # retrieve data for directories above if the path has no data.
+    # This enables to merge information attached to directory by the
+    # user to the files. This information may override some unknown
+    # entries. Anyway, this duplicated information is coaslesced later
+    # on. In other words, this may seem back and forth work, but it's
+    # not because manually entered information at directory level is
+    # merged into the file data.
     if (not $data) {
         foreach my $dir (reverse sort keys $old_split_dirs->%*) {
             my $re = $dir;
@@ -86,12 +94,12 @@ sub update ($self, %args) {
 
     # explode new data and merge with existing entries
     my %new_split_files;
-    my @data = (undef);# id 0 is reserved for entries without info
+    my @new_copyrights_by_id = (undef);# id 0 is reserved for entries without info
     my %data_keys;
     foreach my $path ( sort keys $files->%* ) {
         my $id = $files->{$path};
         next if $id == 0 and not defined $copyrights_by_id->[$id];
-        my ($c, $l) = $copyrights_by_id->[$id]->@*;
+        my ($c, $l) = __from_copyright_structure($copyrights_by_id->[$id]);
 
         my $new_data = _get_old_data(\%old_split_files, \%old_split_dirs, $path);
         my $old_cop = $new_data->{Copyright};
@@ -109,7 +117,7 @@ sub update ($self, %args) {
         my $d_key;
         if ( $new_data->{Copyright} =~ /no-info-found|unknown/i
             and $new_data->{License}{short_name} =~ /unknown/i) {
-            $data[0] //= $new_data;
+            $new_copyrights_by_id[0] //= $new_data;
             $d_key = 0;
         }
         else {
@@ -121,10 +129,12 @@ sub update ($self, %args) {
             $d_key = $data_keys{$datum_dump};
 
             if (not defined $d_key) {
-                push @data,$new_data;
-                # id 0 is special and is treated diffrently. It must not be used since
-                # entries without info are skipped. Hence @data was init with ('');
-                $d_key = $data_keys{$datum_dump} = $#data ;
+                push @new_copyrights_by_id,$new_data;
+                # id 0 is reseved for missing info and is treated
+                # differently. It must not be used since entries
+                # without info are skipped. Hence @new_copyrights_by_id was
+                # initialised with ('');
+                $d_key = $data_keys{$datum_dump} = $#new_copyrights_by_id ;
            }
         }
         # explode path in subpaths and store id pointing to copyright data in there
@@ -132,11 +142,11 @@ sub update ($self, %args) {
     }
 
     # at this point:
-    # * $copyrights_by_id is not longer used, its data and merged data are in @data
-    # * @data contains a list of copyright/license data
+    # * $copyrights_by_id is not longer used, its data and merged data are in @new_copyrights_by_id
+    # * @new_copyrights_by_id contains a list of copyright/license data
     # * %new_split_files contains a tree matching a directory tree where each leaf
     #   is an integer index referencing
-    #   an entry in @data to get the correct  copyright/license data
+    #   an entry in @new_copyrights_by_id to get the correct  copyright/license data
     # * %old_split_files contains paths no longer present. Useful to trace deleted files
 
     my $current_dir = $args{from_dir} || path('.');
@@ -157,7 +167,7 @@ sub update ($self, %args) {
 
 
     # implode files entries with same data index
-    __squash(\%new_split_files) ;
+    __squash(\%new_split_files, \@new_copyrights_by_id) ;
 
     # pack files by copyright id
     my @packed = __pack_files(\%new_split_files);
@@ -171,7 +181,7 @@ sub update ($self, %args) {
     # or a single entry. Skip unknown or public-domain licenses
     my %lic_usage_count;
     map { $lic_usage_count{$_}++ if $_ and not /unknown|public/i}
-        map {split /\s+or\s+/, $data[$_->[0]]->{License}{short_name} // ''; }
+        map {split /\s+or\s+/, $new_copyrights_by_id[$_->[0]]->{License}{short_name} // ''; }
         @packed ;
 
     # load new data in config tree
@@ -180,7 +190,7 @@ sub update ($self, %args) {
 
         next if $id == 0; # skip entries without info
 
-        my $datum = dclone($data[$id]);
+        my $datum = dclone($new_copyrights_by_id[$id]);
 
         # ditch old data when copyright data directory is found in source files
         if ($paths[0] =~ /[*.]$/) {
