@@ -1,4 +1,7 @@
-[
+use strict;
+use warnings;
+
+return [
   {
     'accept' => [
       '.*',
@@ -78,11 +81,16 @@ to know what changes came with a new policy version number and apply the require
         'summary' => 'Debian policy version number this package complies to',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'current' => {
-            'code' => '$_ eq $self->_fetch_std;',
+            'code' => '$self->compare_with_last_version($_) == -1;',
             'fix' => '$_ = $self->_fetch_std; # restore default value',
             'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+'
+          },
+          'old_lintian' => {
+            'code' => '$self->compare_with_last_version($_) == 1;',
+            'msg' => 'Current standards version \'$_\' is newer than lintian version ($std_value). Please check your system
 '
           }
         }
