@@ -1,4 +1,7 @@
-[
+use strict;
+use warnings;
+
+return [
   {
     'author' => [
       'Dominique Dumont'
@@ -31,12 +34,12 @@ The name given must match a License described in License element in root node
 ',
         'grammar' => 'check: <rulevar: local $found = 0> <rulevar: local $ok = 1 >
 check: license alternate(s?) <reject: $text or not $found or not $ok >
-alternate: comma(?) oper license 
+alternate: comma(?) license_association license
 comma: \',\'
-oper: \'and\' | \'or\' 
+license_association: \'and\' | \'or\'
 abbrev: /[^\\s,]+/
-exception: \'with\' abbrev \'exception\' { join(\' \',@item[1..3]); }
-license: abbrev exception(?)
+license_exception: \'with\' abbrev \'exception\' { join(\' \',@item[1..3]); }
+license: abbrev license_exception(?)
    { # PRD action to check if the license text is provided
      my $short_name = $item[1] ;
 	 $short_name .= \' \'.$item[2][0] if $item[2][0] ;
@@ -51,6 +54,7 @@ license: abbrev exception(?)
          my $expected = @known_licenses ? "Expected one of the current stand-alone License paragraphs: @known_licenses."
              : "Did not find any stand-alone License paragraph.";
          ${$arg[1]} .= "license \'$short_name\' is not declared in a stand-alone License paragraph. $expected" ;
+         return undef;
      }
    } ',
         'help' => {
