@@ -16,7 +16,7 @@ no warnings qw/experimental::postderef experimental::signatures/;
 
 binmode STDOUT, ':utf8';
 
-our @EXPORT = qw(scan_files print_copyright);
+our @EXPORT = qw(scan_files print_copyright __from_copyright_structure __to_copyright_structure);
 
 my $whitespace_list_delimiter = $ENV{'whitespace_list_delimiter'} || "\n ";
 
@@ -52,7 +52,7 @@ sub print_copyright ( %args ) {
     }
 
     # regroup %files hash: all leaves have same id -> wild card
-    __squash($split_files);
+    __squash($split_files, $copyrights_by_id);
 
     # pack files by copyright id
     my @packed = __pack_files($split_files);
@@ -61,7 +61,7 @@ sub print_copyright ( %args ) {
 
     foreach my $p (@packed) {
         my ($id, @paths) = $p->@*;
-        my ($c,$l) = $copyrights_by_id->[$id]->@*;
+        my ($c,$l) = __from_copyright_structure($copyrights_by_id->[$id]);
 
         next if $id == 0;
 
@@ -224,6 +224,18 @@ sub scan_files ( %args ) {
         # and it's a collective work by nature.
         next if $f =~  m!debian/(copyright|changelog)!;
 
+        # skip copyright infos extracted from license files when they
+        # come from the author of the license and not from the project
+        # author
+        if ($f =~  m/^COPYING|LICENSE$/) {
+            if ($c =~ /Free Software Foundation/) { next; }
+            if ($c =~ /Perl Foundation/) { next; }
+        }
+
+
+        # skip license files without copyright information (usually plain license)
+        next if $f =~  m/^COPYING|LICENSE$/ && $c =~ /No copyright/;
+
         # filter out files user does not want checked
         if ( $f !~ $regexps{check} ) {
             # the ignore test should not be usefull as the files are ignored by licensecheck
@@ -244,6 +256,10 @@ sub scan_files ( %args ) {
         # $l =~ s/\bBSD \((\d) clause\)/BSD-$1-clause/g;
         # $l =~ s/\bpublic domain\b/public-domain/ig;
 
+        # licensecheck uses and/or when a file contains 2
+        # licenses. and/or is not a valid syntax for debian/copyright
+        # file
+        $l =~ s!and/or!or!g;
 
         # # deduplicate license keywords and add 'or' keyword where missing
         # # this is fragile. may need to change license-check to output license keyword
@@ -334,7 +350,7 @@ sub scan_files ( %args ) {
     foreach my $c (sort keys %copyrights) {
         foreach my $l (sort keys $copyrights{$c}->%* ) {
             my $id = $copyrights{$c}{$l};
-            $copyrights_by_id[$id] = [ $c, $l ] ;
+            $copyrights_by_id[$id] = __to_copyright_structure( $c, $l ) ;
         }
     }
 
@@ -349,6 +365,17 @@ sub scan_files ( %args ) {
     return ($files, \@copyrights_by_id) ;
 }
 
+sub __to_copyright_structure ($c, $l) {
+    return {
+        Copyright => $c,
+        License => { short_name => $l},
+    };
+}
+
+sub __from_copyright_structure ($s) {
+    return ($s->{Copyright}, $s->{License}{short_name});
+}
+
 sub __split_copyright ($c) {
     my ($years,$owner) = $c =~ /^(\d\d[\s,\d-]+)(.*)/;
     # say "undef year in $c" unless defined $years;
@@ -444,7 +471,7 @@ sub __squash_copyrights_years ($copyrights_by_id) {
 
     my %id_year_by_same_owner_license;
     for (my $id = 1; $id < $copyrights_by_id->@* ; $id++ ) {
-        my ($c,$l) = $copyrights_by_id->[$id]->@* ;
+        my ($c, $l) = __from_copyright_structure($copyrights_by_id->[$id]);
         #say "id $id: c $c l $l";
         my @owners ;
         my @years ;
@@ -476,7 +503,7 @@ sub __squash_copyrights_years ($copyrights_by_id) {
         # store (c) info with coalesced years in new item of $copyrights_by_id
         my $new_id = $copyrights_by_id->@* ;
         my $new_cop = join("\n ",@squashed_c) ;
-        $copyrights_by_id->[$new_id] = [ $new_cop , $l ];
+        $copyrights_by_id->[$new_id] = __to_copyright_structure( $new_cop , $l );
         #say "created id $new_id with c $new_cop l $l";
         # fill the swap table entry-id -> coaslesces entry-id
         foreach my $id ( map { $_->[0]} @entries) {
@@ -531,24 +558,49 @@ sub __coalesce_copyright_years($entries, $owners) {
 
 # $h is a tree of hash matching the directory structure. Each leaf is a
 # copyright id. Each key is a file name in a directory (not the full path)
-sub __squash ($h, $p = '') {
+sub __squash ($h, $copyrights_by_id, $p = '') {
     my %count ;
 
-    # find main license info found in LICENCE or COPYING or README
-    # file
-    foreach my $info_name (qw/readme copying license/) {
-        my $re = qr!$info_name[.\w]*$!i;
+    # find main license info found in LICENSE or COPYING or README
+    #  file. LICENSE and COPYING are removed from the file list as
+    #  they specify the license author as copyright owner
+    my %main_infos;
+    foreach my $info_name (qw/README LICENSE LICENCE COPYING/) {
+        my $re = qr!^$info_name[.\w]*$!;
         foreach my $name (sort keys %$h) {
             if ($name =~ $re) {
-                my $id = delete $h->{$name};
+                my $id = $h->{$name};
+                delete $h->{$name} if $info_name ne 'README';
                 next unless $id; # skip files without info
-                # say "del global lic info $p/$name with $id";
-                # using 1 means that info from this file is not easy to override
-                $count{$id} = 1;
+                $main_infos{$id} = 1;
             };
         }
     }
 
+    my $main_license_id;
+    my @main_info_keys = sort keys %main_infos;
+    if (@main_info_keys == 1) {
+        $main_license_id = $main_info_keys[0];
+    }
+    elsif (@main_info_keys > 1) {
+        # create a new copyright id containing a sum of all info found
+        # in README LICENSE (...) files (if they are different and
+        # have actual info)
+        my %licenses;
+        my %copyrights;
+        foreach my $info_id (@main_info_keys) {
+            my ($cop, $lic) = __from_copyright_structure($copyrights_by_id->[$info_id]);
+            $licenses{$lic} = 1 unless $lic =~ /unknown/i;
+            $copyrights{$cop} = 1 unless $cop =~ /unknown|no-info-found/i;;
+        }
+        push $copyrights_by_id->@*,
+            __to_copyright_structure (
+                join("\n", sort keys %copyrights),
+                join(" or ", sort keys %licenses)
+            );
+        $main_license_id = $#$copyrights_by_id;
+    }
+
     # count the number of times each (c) info is used in this directory.
     # (including the main (c) info of each subdirectory)
     foreach my $name (sort keys %$h) {
@@ -556,7 +608,7 @@ sub __squash ($h, $p = '') {
         if (ref($item)) {
             # squash may return a plain id, or a hash with '*' => id ,
             # or a non squashable hash
-            $h->{$name} = __squash($item, $p.'/'.$name);
+            $h->{$name} = __squash($item, $copyrights_by_id, $p.'/'.$name);
         }
         my $id = (ref($item) and defined $item->{'*'}) ? $item->{'*'} : $item ;
 
@@ -568,10 +620,9 @@ sub __squash ($h, $p = '') {
         }
     }
 
-    # find the most used (c) info in this directory (or the existing '*' entry)
+    # find the most used (c) info in this directory
     # unless info was already found in LICENSE or README content
     my $max = 0;
-    my $main_license_id = $h->{'*'};
     if (not defined $main_license_id) {
         foreach my $id (sort keys %count) {
             if ($count{$id} > $max) {
@@ -673,18 +724,43 @@ license information. Information are packed in a way to ease review and
 maintenance. Files information is grouped with wildcards ('*') to reduce
 the list of files.
 
+=head2 About LICENSE and README files
+
+Projects often store global copyright information, i.e. information
+that apply to all files of a project (unless specified otherwise in
+some files) in README or LICENSE or COPYING file.
+
+The information contained in these files id merged and applied to the
+directory entry that contain them.
+
+I.e files like:
+
+ foo_comp/README: (c) 2018 Joe, GPL-2
+ foo_comp/LICENSE: (c) 2017 Max, GPL-3
+
+Yield the following copyright entries:
+
+ foo_comp/*:
+ Copyright: 2018 Joe
+   2019 Max
+ License: GPL-2 or GPL-3
+
+ README:
+ Copyright: 2018 Joe
+ License: GPL-2
+
 =head1 Selecting or ignoring files to scan
 
 By default, scanner scans source files with known suffixes (like .c
 .pl ...), README, scripts and skip backup files.
 
-You can change this behavior in file
-C<debian/copyright-scan-patterns.yml>. This YAML file can contain a
+If needed, this behavior can tuned with
+C<debian/copyright-scan-patterns.yml> file. This YAML file contains a
 list of suffixes or patterns to scan or to ignore that are added to
 the default list. Any file that is not scanned or ignored will be
 shown as "skipped".
 
-The file must have the following structure (all fields are optional
+This file must have the following structure (all fields are optional
 and order does not matter):
 
  ---
