@@ -1,15 +1,14 @@
 use Data::Dumper;
-use IO::File;
 use Path::Tiny;
 use Lintian::Data;
 use Lintian::Profile;
+use Config::Model::Dpkg::Dependency;
 
 use strict;
 use warnings;
 
-our $conf_file_name = "control";
-our $conf_dir       = 'debian';
-our $model_to_test  = "Dpkg::Control";
+my $conf_file_name = "control";
+my $conf_dir       = 'debian';
 
 my $profile = Lintian::Profile->new ('debian');
 Lintian::Data->set_vendor($profile);
@@ -21,7 +20,35 @@ providing the following file:
 
  - xt/release/pod-spell.t - a standard Test::Spelling test" ;
 
-our @tests = (
+my $jellyfish_annotation = << 'EON';
+Package: python3-dna-jellyfish
+Architecture: any
+Section: python
+Depends: ${python3:Depends},
+         ${misc:Depends},
+         ${shlibs:Depends}
+Description: count k-mers in DNA sequences (Python bindings of jellyfish)
+ JELLYFISH is a tool for fast, memory-efficient counting of k-mers in
+ DNA. A k-mer is a substring of length k, and counting the occurrences
+ of all such substrings is a central step in many analyses of DNA
+ sequence. JELLYFISH can count k-mers using an order of magnitude less
+ memory and an order of magnitude faster than other k-mer counting
+ packages by using an efficient encoding of a hash table and by
+ exploiting the "compare-and-swap" CPU instruction to increase
+ parallelism.
+ .
+ JELLYFISH is a command-line program that reads FASTA and multi-FASTA
+ files containing DNA sequences. It outputs its k-mer counts in an
+ binary format, which can be translated into a human-readable text
+ format using the "jellyfish dump" command.
+ .
+ This package contains the Python bindings of jellyfish.
+EON
+    ;
+
+chomp $jellyfish_annotation;
+
+my @tests = (
     {
 
         # t0
@@ -128,8 +155,8 @@ our @tests = (
     {
         name => 'libpango-perl',
         verify_annotation => {
-            'source Build-Depends' => "do NOT add libgtk2-perl to build-deps (see bug #554704)",
-            'source Maintainer'    => "what a fine\nteam this one is",
+            'source Build-Depends' => " do NOT add libgtk2-perl to build-deps (see bug #554704)",
+            'source Maintainer'    => " what a fine\n team this one is",
         },
         apply_fix => 1,
     },
@@ -227,7 +254,7 @@ our @tests = (
     {
         name => 'tricky-comment',
         verify_annotation => {
-            'binary:libmoosex-types-iso8601-perl Synopsis' => "not yet packaged\nRecommends",
+            'binary:libmoosex-types-iso8601-perl Synopsis' => " not yet packaged\n Recommends",
         }
     },
 
@@ -255,7 +282,7 @@ our @tests = (
         name => 'bcftools',
         apply_fix => 1,
         verify_annotation => {
-            'binary:bcftools Suggests:0' => "These are needed for plot-vcfstats"
+            'binary:bcftools Suggests:0' => " These are needed for plot-vcfstats"
         },
         check => {
             'binary:bcftools Suggests:0' => "python"
@@ -313,25 +340,34 @@ our @tests = (
             'source Build-Depends:0' => 'debhelper (>= 11~)',
             'source Build-Depends:1' => 'nodejs',
         }
+    },
+    {
+        # Debian 
+        name => 'jellyfish',
+        verify_annotation => {
+            'binary:libjellyfish-perl' => $jellyfish_annotation,
+            'source Source' => " Dummy source comment\n that should be preserved when writing file backend",
+        }
     }
 );
 
-my $cache_file = 't/model_tests.d/dependency-cache.txt';
+my $cache_file = path('t/model_tests.d/dependency-cache.txt');
 
 $Config::Model::Dpkg::Dependency::use_test_cache = 1;
+untie %Config::Model::Dpkg::Dependency::cache;
+%Config::Model::Dpkg::Dependency::cache = ();
 
-my $ch = new IO::File "$cache_file";
-foreach ($ch->getlines) {
-    chomp;
-    my ($k,$v) = split m/ => / ;
+foreach my $line ($cache_file->lines) {
+    chomp $line;
+    next unless $line;
+    my ($k,$v) = split m/ => /, $line ;
     $Config::Model::Dpkg::Dependency::cache{$k} = time . ' '. $v ;
 }
-$ch -> close ;
 
 END {
     return if $::DebianDependencyCacheWritten ;
     my %h = %Config::Model::Dpkg::Dependency::cache ;
-    map { s/^\d+ //;} values %h ; # remove time stamp
+    do { s/^\d+ //;} for values %h ; # remove time stamp
     my $str = join ("\n", map { "$_ => $h{$_}" ;} sort keys %h) ;
 
     my $fh = new IO::File "> $cache_file";
@@ -344,4 +380,8 @@ END {
     }
 }
 
-1;
+return {
+    conf_file_name => $conf_file_name,
+    conf_dir => $conf_dir,
+    tests => \@tests,
+};
