@@ -2,12 +2,13 @@ use Data::Dumper;
 use IO::File;
 use utf8;
 use Path::Tiny;
+use strict;
+use warnings;
 
-$conf_file_name = "copyright";
-$conf_dir       = 'debian';
-$model_to_test  = "Dpkg::Copyright";
+my $conf_file_name = "copyright";
+my $conf_dir       = 'debian';
 
-@tests = (
+my @tests = (
     { # t0
         log4perl_load_warnings => [[ User => warn => qr/Missing/, (warn => qr/deprecated/) x 3 ]],
         load_check => 'skip',
@@ -365,7 +366,32 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         # not valid: the License short_name for File:"*" is empty.
         name => 'by-dh-make-perl',
         update => { in => path('t/scanner/examples/by-dh-make-perl.in') , quiet => 1 },
-    }
+    },
+
+    {
+        name => 'node-gulp-from-scratch',
+        update => { in => path('t/scanner/examples/node-gulp.in') , quiet => 1 },
+        check => {
+            'Files:"make-iterator/*" Copyright' =>
+                [ qr/moutjs team/, qr/Schlinkert/ ],
+            'Files:"make-iterator/*" License short_name' => 'Expat',
+        }
+    },
+
+    {
+        name => 'node-gulp',
+        update => { in => path('t/scanner/examples/node-gulp.in') , quiet => 1 },
+        check => {
+            # merged info from LICENSE and README file
+            'Files:"make-iterator/*" Copyright' =>
+                [ qr/moutjs team/, qr/Schlinkert/ ],
+            'Files:"make-iterator/*" License short_name' => 'Expat', # merged info
+        }
+    },
 );
 
-1;
+return {
+    conf_file_name => $conf_file_name,
+    conf_dir => $conf_dir,
+    tests => \@tests,
+};
